Module work_query

Module work_query 

Structs

ResponseData
Variables
WorkQueryWork
A written text that can be published
WorkQueryWorkContributions
A person’s involvement in the production of a written text.
WorkQueryWorkContributionsContributor
A person who has been involved in the production of a written text.
WorkQueryWorkImprint
The brand under which a publisher issues works.
WorkQueryWorkImprintPublisher
An organisation that produces and distributes written texts.
WorkQueryWorkLanguages
Description of a work’s language.
WorkQueryWorkPublications
A manifestation of a written text
WorkQueryWorkSubjects
A significant discipline or term related to a work.

Enums

ContributionType
LanguageCode
LanguageRelation
PublicationType
SubjectType
WorkStatus
WorkType

Constants

OPERATION_NAME
QUERY