Module works_query

Module works_query 

Structs

ResponseData
Variables
WorksQueryWorks
A written text that can be published
WorksQueryWorksContributions
A person’s involvement in the production of a written text.
WorksQueryWorksContributionsContributor
A person who has been involved in the production of a written text.
WorksQueryWorksImprint
The brand under which a publisher issues works.
WorksQueryWorksImprintPublisher
An organisation that produces and distributes written texts.

Constants

OPERATION_NAME
QUERY